@@ -1,6 +1,6 @@
 #!perl -w
 #
-# $Id: exe_opt.pl,v 1.13 2006/03/01 04:21:16 rmeden Exp $
+# $Id: exe_opt.pl,v 1.15 2008/11/30 06:49:12 rmeden Exp $
 #
 # This is a simple script to generate options so PerlApp can make the EXE
 # it needs time values, so might as well put it in a perl script!
@@ -14,8 +14,6 @@ use File::Spec;
 #
 # output constants
 #
-#-bind=libexpat.dll[file=\perl\site\lib\auto\XML\Parser\Expat\libexpat.dll,extract]
-#-trim="Convert::EBCDIC;Encode;HASH;HTML::FromText;Text::Iconv;Unicode::Map8;v5;URI/urn::isbn.pm;URI/urn::oid.pm;PerlIO/gzip.pm;HTML::FormatText"
 print '-nologo
 -force
 -add="XMLTV::Ask::Term;XMLTV::Ask::Tk"
@@ -24,7 +22,8 @@ print '-nologo
 -add="Class::MethodMaker::scalar"
 -add="Tk::ProgressBar"
 -bind=libxml2.dll[file=\perl\bin\libxml2.dll,extract]
--trim="Apache::Const;Apache::RequestIO;DIME::Payload;MIME::Entity;Apache::RequestRec;DIME::Message"
+-trim="Apache::Const;Apache::RequestIO;DIME::Payload;MIME::Entity;Apache::RequestRec;DIME::Message;I18N::Langinfo"
+-trim="Apache2::RequestUtil;APR::Table;Apache2::Const;Apache2::RequestRec;Apache2::RequestIO"
 -info CompanyName="XMLTV Project http://www.xmltv.org"
 -info FileDescription="EXE bundle of XMLTV tools to manage TV Listings"
 -info InternalName=xmltv.exe
